@@ -288,6 +288,7 @@ KateCompletionConfigTab::KateCompletionConfigTab(QWidget *parent)
   connect(ui->chkAutoCompletionEnabled, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(ui->gbWordCompletion, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(ui->minimalWordLength, SIGNAL(valueChanged(int)), this, SLOT(slotChanged()));
+  connect(ui->removeTail, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
 
   layout->addWidget(newWidget);
   setLayout(layout);
@@ -314,6 +315,7 @@ void KateCompletionConfigTab::apply ()
   KateViewConfig::global()->setAutomaticCompletionInvocation (ui->chkAutoCompletionEnabled->isChecked());
   KateViewConfig::global()->setWordCompletion (ui->gbWordCompletion->isChecked());
   KateViewConfig::global()->setWordCompletionMinimalWordLength (ui->minimalWordLength->value());
+  KateViewConfig::global()->setWordCompletionRemoveTail (ui->removeTail->isChecked());
   KateViewConfig::global()->configEnd ();
 }
 
@@ -322,6 +324,7 @@ void KateCompletionConfigTab::reload ()
   ui->chkAutoCompletionEnabled->setChecked( KateViewConfig::global()->automaticCompletionInvocation () );
   ui->gbWordCompletion->setChecked( KateViewConfig::global()->wordCompletion () );
   ui->minimalWordLength->setValue (KateViewConfig::global()->wordCompletionMinimalWordLength ());
+  ui->removeTail->setChecked (KateViewConfig::global()->wordCompletionRemoveTail ());
 }
 //END KateCompletionConfigTab
 
@@ -347,7 +350,6 @@ KateViInputModeConfigTab::KateViInputModeConfigTab(QWidget *parent)
 
   connect(ui->chkViInputModeDefault, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(ui->chkViCommandsOverride, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
-  connect(ui->chkViStatusBarHide, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(ui->tblNormalModeMappings, SIGNAL(cellChanged(int,int)), this, SLOT(slotChanged()));
   connect(ui->btnAddNewNormal, SIGNAL(clicked()), this, SLOT(addNewNormalModeMappingRow()));
   connect(ui->btnAddNewNormal, SIGNAL(clicked()), this, SLOT(slotChanged()));
@@ -380,14 +382,17 @@ void KateViInputModeConfigTab::apply ()
   KateViewConfig::global()->configStart ();
   KateViewConfig::global()->setViInputMode (ui->chkViInputModeDefault->isChecked());
   KateViewConfig::global()->setViInputModeStealKeys (ui->chkViCommandsOverride->isChecked());
-  KateViewConfig::global()->setViInputModeHideStatusBar (ui->chkViStatusBarHide->isChecked());
   KateGlobal::self()->viInputModeGlobal()->clearMappings( NormalMode );
   for ( int i = 0; i < ui->tblNormalModeMappings->rowCount(); i++ ) {
     QTableWidgetItem* from = ui->tblNormalModeMappings->item( i, 0 );
     QTableWidgetItem* to = ui->tblNormalModeMappings->item( i, 1 );
+    QTableWidgetItem* recursive = ui->tblNormalModeMappings->item( i, 2 );
 
-    if ( from && to ) {
-      KateGlobal::self()->viInputModeGlobal()->addMapping( NormalMode, from->text(), to->text() );
+    if ( from && to && recursive) {
+      const KateViModeBase::MappingRecursion recursion = recursive->checkState() == Qt::Checked ?
+        KateViModeBase::Recursive :
+        KateViModeBase::NonRecursive;
+      KateGlobal::self()->viInputModeGlobal()->addMapping( NormalMode, from->text(), to->text(), recursion);
     }
   }
   KateViewConfig::global()->configEnd ();
@@ -397,17 +402,18 @@ void KateViInputModeConfigTab::reload ()
 {
   ui->chkViInputModeDefault->setChecked( KateViewConfig::global()->viInputMode () );
   ui->chkViCommandsOverride->setChecked( KateViewConfig::global()->viInputModeStealKeys () );
-  ui->chkViStatusBarHide->setChecked( KateViewConfig::global()->viInputModeHideStatusBar () );
 
   ui->chkViCommandsOverride->setEnabled(ui->chkViInputModeDefault->isChecked());
-  ui->chkViStatusBarHide->setEnabled(ui->chkViInputModeDefault->isChecked());
 
   QStringList l = KateGlobal::self()->viInputModeGlobal()->getMappings( NormalMode );
   ui->tblNormalModeMappings->setRowCount( l.size() );
 
-  // make the two columns fill the entire table width
-  ui->tblNormalModeMappings->setColumnWidth( 0, ui->tblNormalModeMappings->width()/3 );
-  ui->tblNormalModeMappings->horizontalHeader()->setStretchLastSection( true );
+  // Make the two columns fill most of the width.
+  // TODO - note that this has never worked, except by fluke: we don't actual know the table
+  // width at this point.
+  ui->tblNormalModeMappings->setColumnWidth( 0, 4 * ui->tblNormalModeMappings->width()/16 );
+  ui->tblNormalModeMappings->setColumnWidth( 1, 4 * ui->tblNormalModeMappings->width()/16 );
+  ui->tblNormalModeMappings->horizontalHeader()->setStretchLastSection(true);
 
   int i = 0;
   foreach( const QString &f, l ) {
@@ -416,9 +422,17 @@ void KateViInputModeConfigTab::reload ()
     QString s = KateGlobal::self()->viInputModeGlobal()->getMapping( NormalMode, f );
     QTableWidgetItem *to =
       new QTableWidgetItem( KateViKeyParser::self()->decodeKeySequence( s ) );
+    QTableWidgetItem *recursive =
+      new QTableWidgetItem();
+    recursive->setFlags(Qt::ItemIsEnabled | Qt::ItemIsUserCheckable | Qt::ItemIsSelectable);
+    const bool isRecursive = KateGlobal::self()->viInputModeGlobal()->isMappingRecursive(NormalMode, f);
+    recursive->setCheckState(isRecursive ? Qt::Checked : Qt::Unchecked);
 
     ui->tblNormalModeMappings->setItem(i, 0, from);
-    ui->tblNormalModeMappings->setItem(i++, 1, to);
+    ui->tblNormalModeMappings->setItem(i, 1, to);
+    ui->tblNormalModeMappings->setItem(i, 2, recursive);
+
+    i++;
   }
 }
 
@@ -426,6 +440,10 @@ void KateViInputModeConfigTab::addNewNormalModeMappingRow()
 {
   int rows = ui->tblNormalModeMappings->rowCount();
   ui->tblNormalModeMappings->insertRow( rows );
+  QTableWidgetItem *recursive = new QTableWidgetItem();
+  recursive->setFlags(Qt::ItemIsEnabled | Qt::ItemIsUserCheckable | Qt::ItemIsSelectable);
+  recursive->setCheckState(Qt::Unchecked);
+  ui->tblNormalModeMappings->setItem(rows, 2, recursive);
   ui->tblNormalModeMappings->setCurrentCell( rows, 0 );
   ui->tblNormalModeMappings->editItem( ui->tblNormalModeMappings->currentItem() );
 }
@@ -443,12 +461,17 @@ void KateViInputModeConfigTab::importNormalMappingRow()
   while(! stream.atEnd()) {
     QStringList line = stream.readLine().split(" ");
 
+    // TODO - allow recursive mappings to be read.
     if(line.size() > 2 && (line[0] == "noremap" || line[0] == "no"
           || line[0] == "nnoremap" || line [0] == "nn")) {
       int rows = ui->tblNormalModeMappings->rowCount();
       ui->tblNormalModeMappings->insertRow( rows );
       ui->tblNormalModeMappings->setItem(rows, 0, new QTableWidgetItem(line[1]));
       ui->tblNormalModeMappings->setItem(rows, 1, new QTableWidgetItem(line[2]));
+      QTableWidgetItem *recursive = new QTableWidgetItem();
+      recursive->setFlags(Qt::ItemIsEnabled | Qt::ItemIsUserCheckable | Qt::ItemIsSelectable);
+      recursive->setCheckState(Qt::Unchecked);
+      ui->tblNormalModeMappings->setItem(rows, 2, recursive);
     }
   }
 }
@@ -1082,15 +1105,7 @@ void KateSaveConfigTab::defaults()
 KatePartPluginConfigPage::KatePartPluginConfigPage (QWidget *parent)
   : KateConfigPage (parent, "")
 {
-  QVBoxLayout *generalLayout = new QVBoxLayout;
-  generalLayout->setMargin(0);
-  KTabWidget *tabWidget = new KTabWidget(this);
-
-  QWidget *tmpWidget = new QWidget(tabWidget);
-  QVBoxLayout *internalLayout = new QVBoxLayout;
-  QWidget *newWidget = new QWidget(tabWidget);
   QVBoxLayout *layout = new QVBoxLayout;
-  newWidget->setLayout(layout);
   layout->setMargin(0);
 
   plugins.clear();
@@ -1110,16 +1125,9 @@ KatePartPluginConfigPage::KatePartPluginConfigPage (QWidget *parent)
   connect(selector, SIGNAL(configCommitted(QByteArray)), this, SLOT(slotChanged()));
 
   selector->addPlugins(plugins, KPluginSelector::IgnoreConfigFile, i18n("Editor Plugins"), "Editor");
+
   layout->addWidget(selector);
-
-  internalLayout->addWidget(newWidget);
-  tmpWidget->setLayout(internalLayout);
-
-  // add all tabs
-  tabWidget->insertTab(0, tmpWidget, i18n("Plugins"));
-
-  generalLayout->addWidget(tabWidget);
-  setLayout(generalLayout);
+  setLayout(layout);
 }
 
 KatePartPluginConfigPage::~KatePartPluginConfigPage ()
