@@ -878,10 +878,8 @@ function trySameLineComment(cursor)
     if (sc.hasComment)                                      // Is there any comment on a line?
     {
         // Make sure we r not in a comment already
-        if (document.isComment(line, document.firstColumn(line)) &&
-          (document.line(line) != '///')) {
+        if (document.isComment(line, document.firstColumn(line)) && (document.line(line) != '///'))
             return;
-        }
         // If no text after the comment and it still not aligned
         var text_len = sc.before.rtrim().length;
         if (text_len != 0 && sc.after.length == 0 && text_len < gSameLineCommentStartAt)
@@ -890,7 +888,7 @@ function trySameLineComment(cursor)
             document.insertText(
                 line
               , column - 2
-              , String().fill(' ', gSameLineCommentStartAt - text_len)
+              , String().fill(' ', gSameLineCommentStartAt - sc.before.length)
               );
             document.insertText(line, gSameLineCommentStartAt + 2, ' ');
         }
@@ -1080,7 +1078,10 @@ function trySemicolon(cursor)
             if (result == -2)
                 result = -1;
         }
-        else
+        // Make sure we r not inside of `for' statement
+        /// \todo Make sure cursor is really inside of \c for and
+        /// not smth like this: <tt>for (blah; blah; blah) some(arg,;|)</tt>
+        else if (!text.startsWith("for "))
         {
             // Check if next character(s) is ')' and nothing after
             should_proceed = true;
@@ -1573,14 +1574,14 @@ function tryExclamation(cursor)
 /**
  * \brief Handle a space
  *
- * Add '()' pair after some keywords like: \c if, \c while, \c for, \c switch
+ * - add <tt>'()'</tt> pair after some keywords like: \c if, \c while, \c for, \c switch
+ * - add <tt>';'</tt> if space pressed right after \c return, and no text after it
  */
 function tryKeywordsWithBrackets(cursor)
 {
     var line = cursor.line;
     var column = cursor.column;
     var text = document.line(line).ltrim();
-    dbg("text="+text);
     var need_brackets = text == "if "
       || text == "else if "
       || text == "while "
@@ -1593,6 +1594,11 @@ function tryKeywordsWithBrackets(cursor)
         document.insertText(cursor, "()");
         view.setCursorPosition(line, column + 1);
     }
+    else if (text == "return ")
+    {
+        document.insertText(cursor, ";");
+        view.setCursorPosition(line, column);
+    }
 }
 
 /**
