@@ -68,6 +68,7 @@ class KATEPART_TESTS_EXPORT KateViModeBase : public QObject
     KateViModeBase()
       : QObject(),
         m_count(0),
+        m_oneTimeCountOverride(-1),
         m_iscounted(false),
         m_stickyColumn(-1)
     {
@@ -79,23 +80,28 @@ class KATEPART_TESTS_EXPORT KateViModeBase : public QObject
      */
     QString getVerbatimKeys() const;
 
-    virtual void addMapping( const QString &from, const QString &to ) = 0;
+    enum MappingRecursion { Recursive, NonRecursive };
+    virtual void addMapping( const QString &from, const QString &to, MappingRecursion recursion ) = 0;
     virtual const QString getMapping( const QString &from ) const = 0;
     virtual const QStringList getMappings() const = 0;
+    virtual bool isMappingRecursive(const QString& from) const = 0;
     void setCount(unsigned int count) { m_count = count; }
     void setRegister(QChar reg) {m_register =  reg;}
 
-    void error( const QString &errorMsg ) const;
-    void message( const QString &msg ) const;
+    void error( const QString &errorMsg );
+    void message( const QString &msg );
 
+    Range findPattern( const QString& pattern, bool backwards, bool caseSensitive, const Cursor& startFrom, int count = 1 ) const;
   protected:
     // helper methods
+    void yankToClipBoard(QChar chosen_register, QString text);
     bool deleteRange( KateViRange &r, OperationMode mode = LineWise, bool addToRegister = true );
     const QString getRange( KateViRange &r, OperationMode mode = LineWise ) const;
     const QString getLine( int lineNumber = -1 ) const;
     const QChar getCharUnderCursor() const;
     const QString getWordUnderCursor() const;
-    KateViRange findPattern( const QString &pattern, bool backwards = false, int count = 1 ) const;
+    const Range getWordRangeUnderCursor() const;
+    KateViRange findPatternForMotion( const QString& pattern, bool backwards, bool caseSensitive, const Cursor& startFrom, int count = 1 ) const;
     Cursor findNextWordStart( int fromLine, int fromColumn, bool onlyCurrentLine = false ) const;
     Cursor findNextWORDStart( int fromLine, int fromColumn, bool onlyCurrentLine = false ) const;
     Cursor findPrevWordStart( int fromLine, int fromColumn, bool onlyCurrentLine = false ) const;
@@ -125,7 +131,13 @@ class KATEPART_TESTS_EXPORT KateViModeBase : public QObject
     unsigned int linesDisplayed() { return m_viewInternal->linesDisplayed(); }
     void scrollViewLines( int l ) { m_viewInternal->scrollViewLines( l ); }
 
-    unsigned int getCount() const { return ( m_count > 0 ) ? m_count : 1; }
+    unsigned int getCount() const {
+      if (m_oneTimeCountOverride != -1)
+      {
+        return m_oneTimeCountOverride;
+      }
+      return ( m_count > 0 ) ? m_count : 1;
+    }
     bool isCounted() { return m_iscounted; }
 
     bool startNormalMode();
@@ -136,7 +148,7 @@ class KATEPART_TESTS_EXPORT KateViModeBase : public QObject
     bool startReplaceMode();
 
     QChar getChosenRegister( const QChar &defaultReg ) const;
-    QString getRegisterContent( const QChar &reg ) const;
+    QString getRegisterContent( const QChar &reg );
     OperationMode getRegisterFlag( const QChar &reg ) const;
     void fillRegister( const QChar &reg, const QString &text, OperationMode flag = CharWise);
 
@@ -150,6 +162,7 @@ class KATEPART_TESTS_EXPORT KateViModeBase : public QObject
 
     KateViRange m_commandRange;
     unsigned int m_count;
+    int m_oneTimeCountOverride;
     bool m_iscounted;
 
     QString m_extraWordCharacters;
@@ -166,6 +179,9 @@ class KATEPART_TESTS_EXPORT KateViModeBase : public QObject
     KateView *m_view;
     KateViewInternal *m_viewInternal;
     KateViInputModeManager* m_viInputModeManager;
+
+    // info message of vi mode
+    QPointer<KTextEditor::Message> m_infoMessage;
 };
 
 #endif
